# coding: utf-8

"""A Python translator from spanish to latiñol

See: https://github.com/thagat/latinol/
"""
from distutils.core import setup

setup(
    name = 'latinol',
    packages = ['latinol'],
    version = '0.1.2',
    description = 'A Python translator from spanish to laniñol',
    author = 'José Sazo',
    author_email = 'jose.sazo@gmail.com',
    url = 'https://github.com/hso/latinol.py',
    download_url = 'https://github.com/hso/latinol.py/tarball/0.1.2',
    keywords = ['text', 'translator', 'fun'],
    classifiers = [
        'Development Status :: 3 - Alpha',
],
)
